sqlobject.mysql.mysqlconnection module — SQLObject 3.9.1 documentation

# sqlobject.mysql.mysqlconnection module

class `sqlobject.mysql.mysqlconnection.` `ErrorMessage`(e, append_msg='')

  Bases: `str`

class `sqlobject.mysql.mysqlconnection.` `MySQLConnection`(db, user, password='', host='localhost', port=0, **kw)

  Bases: `sqlobject.dbconnection.DBAPI`

  `addColumn`(tableName, column)
  `can_use_json_funcs`()
  `can_use_microseconds`()
  `columnsFromSchema`(tableName, soClass)
  `createColumn`(soClass, col)
  `createEmptyDatabase`()

    Create an empty database.

  `createIDColumn`(soClass)
  `createIndexSQL`(soClass, index)
  `createReferenceConstraint`(soClass, col)
  `dbName` = 'mysql'
  `delColumn`(sqlmeta, column)
  `dropDatabase`()
  `guessClass`(t)
  `joinSQLType`(join)
  `listDatabases`()
  `listTables`()
  `makeConnection`()
  `odbc_keywords` = ('Server', 'Port', 'UID', 'Password', 'Database')
  `schemes` = ['mysql']
  `server_version`()
  `supportTransactions` = False
  `tableExists`(tableName)